Module: Olap::View
- Defined in:
- lib/olap/view.rb,
lib/olap/view/engine.rb,
lib/olap/view/version.rb
Defined Under Namespace
Constant Summary collapse
- VERSION =
"0.0.16"- @@view_options =
{ no_data: "Not enough data to display", undefined: "-", total: "Total" }
Class Method Summary collapse
-
.default_options=(options = {}) ⇒ Object
Configure the default options to connect to XMLA server Can be optionally used to setup connection options in one place in application,.
- .options ⇒ Object
- .request(mdx, args = {}) ⇒ Object
Class Method Details
.default_options=(options = {}) ⇒ Object
Configure the default options to connect to XMLA server Can be optionally used to setup connection options in one place in application,
Example:
>> Olap::View.default_options = {no_data: 'Text for no data', undefined: 'Undefined element name', total: 'Total title'}
>> Olap::View.request mdx
=> #<Olap::View::Parse:0x007ffa2b9f60f0 @response=#<Olap::Xmla::Response:0x007ffa2b9f6118 @response={4 ...
26 27 28 |
# File 'lib/olap/view.rb', line 26 def self. = {} @@view_options.merge() end |
.options ⇒ Object
30 31 32 |
# File 'lib/olap/view.rb', line 30 def self. @@view_options end |